@@ -1,8 +1,11 @@
 #!/bin/bash
 # Push to pypi, tag and push to bitbucket
 
+# Fail on 1'st error
+set -e
+
 make
-python setup.py bdist_egg upload
+python3 setup.py bdist_egg upload
 python2 setup.py bdist_egg upload
 python setup.py sdist upload
 rm -fr build dist
