@@ -6,8 +6,13 @@
 echo "[$(date)] Running tests on $(hostname) [user=${USER}, pwd=${PWD}]"
 echo
 
+echo "running flake8"
+flake8 fastavro tests
+if [ $? -ne 0 ]; then
+    exit $?
+fi
+
 nose=${nose-nosetests}
 echo "nose is $nose"
 
-
 $nose -vd $@ tests
